@@ -2,6 +2,7 @@
  *  xfdesktop - xfce4's desktop manager
  *
  *  Copyright (c) 2004 Brian Tarricone, <bjt23@cornell.edu>
+ *  Copyright (c) 2010 Jannis Pohlmann, <jannis@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,6 +49,26 @@
 #define WINDOWLIST_MESSAGE "windowlist"
 #define QUIT_MESSAGE       "quit"
 
+/**
+ * File information namespaces queried for #GFileInfo objects.
+ */
+#define XFDESKTOP_FILE_INFO_NAMESPACE \
+  "access::*," \
+  "id::*," \
+  "mountable::*," \
+  "preview::*," \
+  "standard::*," \
+  "time::*," \
+  "thumbnail::*," \
+  "trash::*," \
+  "unix::*"
+
+/**
+ * Filesystem information namespaces queried for #GFileInfo * objects.
+ */
+#define XFDESKTOP_FILESYSTEM_INFO_NAMESPACE \
+  "filesystem::*"
+
 G_BEGIN_DECLS
 
 gchar **xfdesktop_backdrop_list_load(const gchar *filename,
